/*
 * Copyright (C) 2022 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */

// Entry point for the contacts-wrest tool
package main

import (
	"encoding/json"
	"flag"
	"fmt"
	"os"
	wrest "ssa/contacts_wrest/wrest"
	"strings"
)

func main() {
	jsonMode := flag.Bool("j", false, "Output a JSON-friendly list of strings instead of human-friendly list")

	// Parse the CLI arguments
	flag.Parse()

	// We must have one argument: the project code
	if flag.NArg() != 1 {
		fmt.Printf("Usage: %v [-j] <PROJECT-CODE>\n", os.Args[0])
		os.Exit(1)
	}

	// Obtain the contacts for this project
	proposalId := flag.Arg(0)
	contacts, err := wrest.RetrieveContacts(proposalId)

	if err != nil {
		fmt.Fprintf(os.Stderr, "Unable to retrieve contacts for %s: %v\n", proposalId, err)
		os.Exit(1)
	}

	if *jsonMode {
		// In JSON mode, we output using the JSON marshaller
		binary, _ := json.Marshal(contacts)
		fmt.Println(string(binary))
	} else {
		// In non-JSON mode, we output something human-friendly
		fmt.Println(strings.Join(contacts, ", "))
	}
}
