#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
import time


def retry(tries=5, delay=2, backoff=2, logger=None):
    def decorator_retry_wrapper(func):
        def function_retry_wrapper(*args, **kargs):
            mutable_tries, mutable_delay = tries, delay
            while mutable_tries > 1:
                try:
                    # try function
                    return func(*args, **kargs)
                except Exception as e:
                    msg = "%s, Retrying in %d seconds..." % (str(e), mutable_delay)
                    if logger:
                        logger.info(msg)

                    # sleep for delay amount in seconds
                    time.sleep(mutable_delay)
                    # decrement tries
                    mutable_tries -= 1
                    # muliply deplay by backoff amount (delay*2)
                    mutable_delay *= backoff
            return func(*args, **kargs)

        return function_retry_wrapper

    return decorator_retry_wrapper
