#!/usr/bin/env bash
#
# Copyright (C) 2022 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
# Helper script to generate alembic migration file
#
set -o nounset -o posix -o xtrace

SCRIPT_DIR=$(dirname "${BASH_SOURCE[0]}")

MESSAGE=""
VENV_PATH="$SCRIPT_DIR/venv"
HELP=0

# Print the usage statement
Help() {
  echo "Generate an alembic migration file"
  echo
  echo "USAGE: migrate-alembic.sh -m 'message in quotes' -p /path/to/venv/"
  echo "options:"
  echo "m   Provide a text description of the database changes to be made"
  echo "p   Provide a path to a venv to be created (default: $VENV_PATH)"
  echo "h   Print this usage statement"
  echo
}

while getopts m:p:h flag; do
  case "${flag}" in
    m)
      MESSAGE=${OPTARG}
      ;;
    p)
      VENV_PATH=${OPTARG}
      ;;
    h)
      HELP=1
      ;;
  esac
done

# Make sure flags are set
if [[ $HELP -eq 1 ]] || [[ -z $MESSAGE ]]; then
  Help
  exit
fi

# Generate the file
python3 -m venv $VENV_PATH
source "$VENV_PATH/bin/activate"
pip3 install -r "$SCRIPT_DIR/requirements.txt"
cd $SCRIPT_DIR && alembic revision -m "$MESSAGE"
